---
name: Bug 反馈
about: 有一个bug需要解决
title: 发现一枚bug
labels: bug
assignees: Cuizi7

---

# 提 ISSUE 须知

请先阅读文档 [rqalpha文档](http://rqalpha.readthedocs.io/)

如果仍有问题的话请在 [issue列表](https://github.com/ricequant/rqalpha/issues) 中寻找是否有相关问题的解决方案

如果没有的话 麻烦开一个issue 描述以下问题：

## 1. RQAlpha的版本

## 2. Python的版本

## 3. 是Windows/Linux/MacOS or others?

## 4. 您出现问题对应的源码/或者能复现问题的简易代码 以及对应的配置

## 5. 您出现的错误堆栈日志信息
